# pytauri-wheel

## [Unreleased]

## [0.4.0]

the first release

[unreleased]: https://github.com/pytauri/pytauri/tree/HEAD
[0.4.0]: https://github.com/pytauri/pytauri/releases/tag/py/pytauri-wheel/v0.4.0
